#!/bin/sh
#
# Copyright (C) 2017  Patrick McDermott
#
# This file is part of the ProteanOS Archive Manager.
#
# The ProteanOS Archive Manager is free software: you can redistribute
# it and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# The ProteanOS Archive Manager is distributed in the hope that it
# will be useful, but WITHOUT ANY WARRANTY; without even the implied
# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with the ProteanOS Archive Manager.  If not, see
# <http://www.gnu.org/licenses/>.

. ${0%/*}/aux/init.sh
. tap-functions.sh
. opk.sh

plan_ 9

changes="$(make_opks_and_changes 'foo' 'foo bar' '1.0-1' 'arch' 'plat' 'trunk' \
	'base')"

command_ok_ 'pro-archman include' -- "${PRO_ARCHMAN}" -v -b 'archive/' include \
	"${changes}"

changes="$(make_opks_and_changes 'foo' 'foo' '1.0-2' 'arch' 'plat' 'trunk' \
	'base')"

command_ok_ 'pro-archman include' -- "${PRO_ARCHMAN}" -v -b 'archive/' include \
	"${changes}"

command_ok_ 'old package "foo" in pool' -- \
	[ -f 'archive/pool/f/foo/foo_1.0-1_arch_plat.opk' ]
command_ok_ 'old package "bar" in pool' -- \
	[ -f 'archive/pool/f/foo/bar_1.0-1_arch_plat.opk' ]
command_ok_ 'new package "foo" in pool' -- \
	[ -f 'archive/pool/f/foo/foo_1.0-2_arch_plat.opk' ]
command_ok_ 'new package "bar" not in pool' -- \
	not [ -f 'archive/pool/f/foo/bar_1.0-2_arch_plat.opk' ]

got_packages='archive/feeds/dev/trunk/arch/plat/base/Packages'
cat >'Packages.exp' <<-EOF
	Package: foo
	Source: foo
	Version: 1.0-2
	Architecture: arch
	Platform: plat
	Maintainer: "J. Random Hacker" <jrandom@example.com>
	Filename: ../../../../../../pool/f/foo/foo_1.0-2_arch_plat.opk
	$(grep '^Size: ' "${got_packages}" | sed -n '1{ p; q; }')
	$(grep '^MD5sum: ' "${got_packages}" | sed -n '1{ p; q; }')
	$(grep '^SHA256sum: ' "${got_packages}" | sed -n '1{ p; q; }')
	
	EOF
command_ok_ 'packages index OK' -- diff -u 'Packages.exp' "${got_packages}"

command_ok_ 'package "foo" MD5sum OK' -- \
	[ "x$(md5sum 'archive/pool/f/foo/foo_1.0-2_arch_plat.opk' | \
		sed 's/ .*$//')" \
	= "x$(sed -n 's/^MD5sum: //p;' "${got_packages}" | \
		sed -n '1{ p; q; }')" ]
command_ok_ 'package "foo" SHA256sum OK' -- \
	[ "x$(sha256sum 'archive/pool/f/foo/foo_1.0-2_arch_plat.opk' | \
		sed 's/ .*$//')" \
	= "x$(sed -n 's/^SHA256sum: //p;' "${got_packages}" | \
		sed -n '1{ p; q; }')" ]

:
